@@ -15,17 +15,10 @@
 #
 # @author: Stéphane Albert
 #
-from oslo.config import cfg
-from oslo_log import log as logging
-
 from cloudkitty.common import rpc
 from cloudkitty import orchestrator
 from cloudkitty import service
 
-LOG = logging.getLogger(__name__)
-
-CONF = cfg.CONF
-
 
 def main():
     service.prepare_service()
