@@ -15,10 +15,9 @@
 #
 # @author: Stéphane Albert
 #
-from oslo.db import exception
-from oslo.db.sqlalchemy import utils
-from oslo.utils import uuidutils
-from oslo_log import log as logging
+from oslo_db import exception
+from oslo_db.sqlalchemy import utils
+from oslo_utils import uuidutils
 import six
 import sqlalchemy
 
@@ -27,8 +26,6 @@ from cloudkitty.rating.hash.db import api
 from cloudkitty.rating.hash.db.sqlalchemy import migration
 from cloudkitty.rating.hash.db.sqlalchemy import models
 
-LOG = logging.getLogger(__name__)
-
 
 def get_backend():
     return HashMap()
