@@ -18,6 +18,21 @@
 import abc
 
 import six
+from stevedore import extension
+
+TRANSFORMERS_NAMESPACE = 'cloudkitty.transformers'
+
+
+def get_transformers():
+    transformers = {}
+    transformer_exts = extension.ExtensionManager(
+        TRANSFORMERS_NAMESPACE,
+        invoke_on_load=True)
+    for transformer in transformer_exts:
+        t_name = transformer.name
+        t_obj = transformer.obj
+        transformers[t_name] = t_obj
+    return transformers
 
 
 @six.add_metaclass(abc.ABCMeta)
